@@ -24,7 +24,12 @@ AWS_CONFIG_PATH = f'{Path.home()}/.aws/config'
 AWS_CREDENTIAL_PATH = f'{Path.home()}/.aws/credentials'
 AWS_SSO_CACHE_PATH = f'{Path.home()}/.aws/sso/cache'
 AWS_DEFAULT_REGION = 'us-west-1'
-CURRENT_REGION = os.getenv('AWS_REGION')
+CURRENT_REGION = 
+try: 
+    CURRENT_REGION = os.getenv('AWS_REGION')
+except: 
+    current_session = boto3.session.Session()
+    CURRENT_REGION = current_session.region_name
 
 default_config = {
   'sso_start_url': 'https://hireteammate.awsapps.com/start',
